summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorjacobkeeler <jacob.keeler@livioradio.com>2020-01-07 13:49:28 -0500
committerjacobkeeler <jacob.keeler@livioradio.com>2020-01-07 13:49:28 -0500
commit7731665a4e49417f6ee68f0bf7e9cf743d168e31 (patch)
treeeadba0eadc1e3fe78a9d6ac95f80ae7e23e282d4
parent0fff71bae9c5ef07ca5505ca81951c5951f6a988 (diff)
downloadsdl_core-fix/various_typos.tar.gz
Fix various typosfix/various_typos
-rw-r--r--src/appMain/smartDeviceLink.ini10
-rw-r--r--src/components/application_manager/rpc_plugins/sdl_rpc_plugin/include/sdl_rpc_plugin/commands/mobile/reset_global_properties_request.h10
-rw-r--r--src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/commands/mobile/reset_global_properties_request.cc30
-rw-r--r--src/components/application_manager/rpc_plugins/sdl_rpc_plugin/test/commands/mobile/reset_global_properties_test.cc12
-rw-r--r--src/components/application_manager/rpc_plugins/sdl_rpc_plugin/test/commands/mobile/set_global_properties_test.cc2
-rw-r--r--src/components/application_manager/src/helpers/application_helper.cc2
-rw-r--r--src/components/application_manager/src/message_helper/message_helper.cc8
-rw-r--r--src/components/application_manager/test/application_helper_test.cc2
-rw-r--r--src/components/application_manager/test/resumption/resumption_data_test.cc7
-rw-r--r--src/components/config_profile/include/config_profile/profile.h8
-rw-r--r--src/components/config_profile/src/profile.cc14
-rw-r--r--src/components/config_profile/test/profile_test.cc8
-rw-r--r--src/components/config_profile/test/smartDeviceLink.ini6
-rw-r--r--src/components/config_profile/test/smartDeviceLink_invalid_boolean.ini6
-rw-r--r--src/components/config_profile/test/smartDeviceLink_invalid_int.ini6
-rw-r--r--src/components/config_profile/test/smartDeviceLink_invalid_pairs.ini6
-rw-r--r--src/components/config_profile/test/smartDeviceLink_invalid_string.ini6
-rw-r--r--src/components/config_profile/test/smartDeviceLink_test.ini8
-rw-r--r--src/components/connection_handler/test/smartDeviceLink.ini6
-rw-r--r--src/components/include/application_manager/application_manager_settings.h2
-rw-r--r--src/components/include/test/application_manager/mock_application_manager_settings.h2
-rw-r--r--src/components/policy/policy_external/include/policy/policy_table/types.h3
-rw-r--r--src/components/policy/policy_external/src/policy_manager_impl.cc2
-rw-r--r--src/components/policy/policy_external/src/policy_table/types.cc4
-rw-r--r--src/components/policy/policy_regular/include/policy/policy_table/types.h3
-rw-r--r--src/components/policy/policy_regular/src/policy_table/types.cc4
26 files changed, 89 insertions, 88 deletions
diff --git a/src/appMain/smartDeviceLink.ini b/src/appMain/smartDeviceLink.ini
index baf8cf6073..84c0be43dd 100644
--- a/src/appMain/smartDeviceLink.ini
+++ b/src/appMain/smartDeviceLink.ini
@@ -131,13 +131,13 @@ AudioDataStoppedTimeout = 1000
VideoDataStoppedTimeout = 1000
[GLOBAL PROPERTIES]
-; HelpPromt and TimeOutPrompt is a vector of strings separated by comma
+; HelpPrompt and TimeOutPrompt is a vector of strings separated by comma
; Delimiter, which will be appended to each TTS chunk, e.g. helpPrompt/timeoutPrompt
TTSDelimiter = ,
; Default prompt items, separated by comma
-HelpPromt = Please speak one of the following commands,Please say a command
+HelpPrompt = Please speak one of the following commands,Please say a command
; Default prompt items, separated by comma
-TimeOutPromt = Please speak one of the following commands,Please say a command
+TimeOutPrompt = Please speak one of the following commands,Please say a command
HelpTitle = Available Vr Commands List
; In case mobile app didn't send global properties default global properties will be sent after this timeout in seconds
; max value TTSGlobalPropertiesTimeout 64K
@@ -233,7 +233,7 @@ MaximumPayloadSize = 131072
FrequencyCount = 1000
FrequencyTime = 1000
; Enable filtering transport data stream
-; On #MalformedMessageFiltering disable SDl disconnect with the first
+; On #MalformedMessageFiltering disable SDL disconnect with the first
; malformed message detection
MalformedMessageFiltering = true
; Boundary values of malformed message detection for connection close
@@ -272,7 +272,7 @@ AppIconsAmountToRemove = 1
; Audio service packet with payload bigger than this value will be marked as a malformed,
; if not specified, this value will default to MaxPayloadSize
;MaximumAudioPayloadSize = 131072
-; Video service packet with payloadbigger than this value will be marked as a malformed,
+; Video service packet with payload bigger than this value will be marked as a malformed,
; if not specified, this value will default to MaxPayloadSize
;MaximumVideoPayloadSize = 131072
diff --git a/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/include/sdl_rpc_plugin/commands/mobile/reset_global_properties_request.h b/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/include/sdl_rpc_plugin/commands/mobile/reset_global_properties_request.h
index 880fced6ba..5643a74227 100644
--- a/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/include/sdl_rpc_plugin/commands/mobile/reset_global_properties_request.h
+++ b/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/include/sdl_rpc_plugin/commands/mobile/reset_global_properties_request.h
@@ -85,26 +85,24 @@ class ResetGlobalPropertiesRequest
private:
/*
- * @brief Sets default value of the HELPPROMT global property
+ * @brief Sets default value of the HELPPROMPT global property
* to the first vrCommand of each Command Menu registered in application
*
* @param app Registered application
- * @param is_timeout_promp Flag indicating that timeout prompt
- * should be reset
*
* @return TRUE on success, otherwise FALSE
*/
- bool ResetHelpPromt(app_mngr::ApplicationSharedPtr app);
+ bool ResetHelpPrompt(app_mngr::ApplicationSharedPtr app);
/*
- * @brief Sets default value of the TIMEOUTPROMT global property
+ * @brief Sets default value of the TIMEOUTPROMPT global property
* to the first vrCommand of each Command Menu registered in application
*
* @param app Registered application
*
* @return TRUE on success, otherwise FALSE
*/
- bool ResetTimeoutPromt(application_manager::ApplicationSharedPtr const app);
+ bool ResetTimeoutPrompt(application_manager::ApplicationSharedPtr const app);
/*
* @brief Sets default value of the VRHELPTITLE global property
diff --git a/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/commands/mobile/reset_global_properties_request.cc b/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/commands/mobile/reset_global_properties_request.cc
index ffd8a7dc81..d79a686c0b 100644
--- a/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/commands/mobile/reset_global_properties_request.cc
+++ b/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/commands/mobile/reset_global_properties_request.cc
@@ -80,7 +80,7 @@ void ResetGlobalPropertiesRequest::Run() {
LOG4CXX_INFO(logger_, "RemoveAppFromTTSGlobalPropertiesList");
application_manager_.RemoveAppFromTTSGlobalPropertiesList(app_id);
- bool helpt_promt = false;
+ bool help_prompt = false;
bool timeout_prompt = false;
bool vr_help_title_items = false;
bool menu_name = false;
@@ -95,9 +95,9 @@ void ResetGlobalPropertiesRequest::Run() {
(*message_)[strings::msg_params][strings::properties][i].asInt());
if (mobile_apis::GlobalProperty::HELPPROMPT == global_property) {
- helpt_promt = ResetHelpPromt(app);
+ help_prompt = ResetHelpPrompt(app);
} else if (mobile_apis::GlobalProperty::TIMEOUTPROMPT == global_property) {
- timeout_prompt = ResetTimeoutPromt(app);
+ timeout_prompt = ResetTimeoutPrompt(app);
} else if (((mobile_apis::GlobalProperty::VRHELPTITLE == global_property) ||
(mobile_apis::GlobalProperty::VRHELPITEMS ==
global_property)) &&
@@ -119,7 +119,7 @@ void ResetGlobalPropertiesRequest::Run() {
StartAwaitForInterface(HmiInterfaces::HMI_INTERFACE_UI);
}
- if (timeout_prompt || helpt_promt) {
+ if (timeout_prompt || help_prompt) {
StartAwaitForInterface(HmiInterfaces::HMI_INTERFACE_TTS);
}
@@ -171,12 +171,12 @@ void ResetGlobalPropertiesRequest::Run() {
hmi_apis::FunctionID::UI_SetGlobalProperties, &msg_params, true);
}
- if (timeout_prompt || helpt_promt) {
+ if (timeout_prompt || help_prompt) {
// create ui request
smart_objects::SmartObject msg_params =
smart_objects::SmartObject(smart_objects::SmartType_Map);
- if (helpt_promt) {
+ if (help_prompt) {
msg_params[strings::help_prompt] = (*app->help_prompt());
}
@@ -191,7 +191,7 @@ void ResetGlobalPropertiesRequest::Run() {
}
}
-bool ResetGlobalPropertiesRequest::ResetHelpPromt(
+bool ResetGlobalPropertiesRequest::ResetHelpPrompt(
application_manager::ApplicationSharedPtr app) {
if (!app) {
LOG4CXX_ERROR(logger_, "Null pointer");
@@ -204,7 +204,7 @@ bool ResetGlobalPropertiesRequest::ResetHelpPromt(
return true;
}
-bool ResetGlobalPropertiesRequest::ResetTimeoutPromt(
+bool ResetGlobalPropertiesRequest::ResetTimeoutPrompt(
application_manager::ApplicationSharedPtr const app) {
if (!app) {
LOG4CXX_ERROR(logger_, "Null pointer");
@@ -212,21 +212,21 @@ bool ResetGlobalPropertiesRequest::ResetTimeoutPromt(
return false;
}
- const std::vector<std::string>& time_out_promt =
- application_manager_.get_settings().time_out_promt();
+ const std::vector<std::string>& time_out_prompt =
+ application_manager_.get_settings().time_out_prompt();
- smart_objects::SmartObject so_time_out_promt =
+ smart_objects::SmartObject so_time_out_prompt =
smart_objects::SmartObject(smart_objects::SmartType_Array);
- for (uint32_t i = 0; i < time_out_promt.size(); ++i) {
+ for (uint32_t i = 0; i < time_out_prompt.size(); ++i) {
smart_objects::SmartObject timeoutPrompt =
smart_objects::SmartObject(smart_objects::SmartType_Map);
- timeoutPrompt[strings::text] = time_out_promt[i];
+ timeoutPrompt[strings::text] = time_out_prompt[i];
timeoutPrompt[strings::type] = hmi_apis::Common_SpeechCapabilities::SC_TEXT;
- so_time_out_promt[i] = timeoutPrompt;
+ so_time_out_prompt[i] = timeoutPrompt;
}
- app->set_timeout_prompt(so_time_out_promt);
+ app->set_timeout_prompt(so_time_out_prompt);
return true;
}
diff --git a/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/test/commands/mobile/reset_global_properties_test.cc b/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/test/commands/mobile/reset_global_properties_test.cc
index 98c0ad098a..d5a4fc1c91 100644
--- a/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/test/commands/mobile/reset_global_properties_test.cc
+++ b/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/test/commands/mobile/reset_global_properties_test.cc
@@ -145,7 +145,7 @@ TEST_F(ResetGlobalPropertiesRequestTest, Run_InvalidVrHelp_UNSUCCESS) {
std::vector<std::string> time_out_prompt;
time_out_prompt.push_back("time_out");
- EXPECT_CALL(app_mngr_settings_, time_out_promt())
+ EXPECT_CALL(app_mngr_settings_, time_out_prompt())
.WillOnce(ReturnRef(time_out_prompt));
smart_objects::SmartObject timeout_prompt =
@@ -196,7 +196,7 @@ TEST_F(ResetGlobalPropertiesRequestTest, Run_SUCCESS) {
std::vector<std::string> time_out_prompt;
time_out_prompt.push_back("time_out");
- EXPECT_CALL(app_mngr_settings_, time_out_promt())
+ EXPECT_CALL(app_mngr_settings_, time_out_prompt())
.WillOnce(ReturnRef(time_out_prompt));
smart_objects::SmartObject timeout_prompt =
@@ -306,7 +306,7 @@ TEST_F(ResetGlobalPropertiesRequestTest,
std::vector<std::string> time_out_prompt;
time_out_prompt.push_back("time_out");
- EXPECT_CALL(app_mngr_settings_, time_out_promt())
+ EXPECT_CALL(app_mngr_settings_, time_out_prompt())
.WillOnce(ReturnRef(time_out_prompt));
EXPECT_CALL(*mock_app_, set_timeout_prompt(_));
@@ -405,7 +405,7 @@ TEST_F(ResetGlobalPropertiesRequestTest,
std::vector<std::string> time_out_prompt;
time_out_prompt.push_back("time_out");
- EXPECT_CALL(app_mngr_settings_, time_out_promt())
+ EXPECT_CALL(app_mngr_settings_, time_out_prompt())
.WillOnce(ReturnRef(time_out_prompt));
EXPECT_CALL(*mock_app_, set_timeout_prompt(_));
@@ -472,7 +472,7 @@ TEST_F(ResetGlobalPropertiesRequestTest,
std::vector<std::string> time_out_prompt;
time_out_prompt.push_back("time_out");
- EXPECT_CALL(app_mngr_settings_, time_out_promt())
+ EXPECT_CALL(app_mngr_settings_, time_out_prompt())
.WillOnce(ReturnRef(time_out_prompt));
EXPECT_CALL(*mock_app_, set_timeout_prompt(_));
@@ -538,7 +538,7 @@ TEST_F(ResetGlobalPropertiesRequestTest,
std::vector<std::string> time_out_prompt;
time_out_prompt.push_back("time_out");
- EXPECT_CALL(app_mngr_settings_, time_out_promt())
+ EXPECT_CALL(app_mngr_settings_, time_out_prompt())
.WillOnce(ReturnRef(time_out_prompt));
EXPECT_CALL(*mock_app_, set_timeout_prompt(_));
diff --git a/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/test/commands/mobile/set_global_properties_test.cc b/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/test/commands/mobile/set_global_properties_test.cc
index 9b72d41f7e..50d20eb825 100644
--- a/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/test/commands/mobile/set_global_properties_test.cc
+++ b/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/test/commands/mobile/set_global_properties_test.cc
@@ -109,7 +109,7 @@ class SetGlobalPropertiesRequestTest
msg_params[am::strings::vr_help_title] = "vr_help_title";
msg_params[am::strings::vr_help][0][am::strings::text] = "vr_help";
msg_params[am::strings::vr_help][0][am::strings::position] = 1u;
- msg_params[am::strings::help_prompt][0][am::strings::text] = "help_promt";
+ msg_params[am::strings::help_prompt][0][am::strings::text] = "help_prompt";
(*msg)[am::strings::msg_params] = msg_params;
return msg;
diff --git a/src/components/application_manager/src/helpers/application_helper.cc b/src/components/application_manager/src/helpers/application_helper.cc
index fc86eb5e62..60dc2b05f5 100644
--- a/src/components/application_manager/src/helpers/application_helper.cc
+++ b/src/components/application_manager/src/helpers/application_helper.cc
@@ -49,7 +49,7 @@ void DeleteGlobalProperties(ApplicationSharedPtr app,
using namespace smart_objects;
const std::vector<std::string>& timeout_prompt =
- app_manager.get_settings().time_out_promt();
+ app_manager.get_settings().time_out_prompt();
SmartObject so_default_timeout_prompt = SmartObject(SmartType_Array);
diff --git a/src/components/application_manager/src/message_helper/message_helper.cc b/src/components/application_manager/src/message_helper/message_helper.cc
index fb0c9f15bf..777216a55d 100644
--- a/src/components/application_manager/src/message_helper/message_helper.cc
+++ b/src/components/application_manager/src/message_helper/message_helper.cc
@@ -2561,7 +2561,7 @@ void MessageHelper::SendOnPermissionsChangeNotification(
uint32_t connection_key,
const policy::Permissions& permissions,
ApplicationManager& app_mngr,
- const policy::EncryptionRequired encryprion_required) {
+ const policy::EncryptionRequired encryption_required) {
LOG4CXX_AUTO_TRACE(logger_);
smart_objects::SmartObject content(smart_objects::SmartType_Map);
@@ -2578,9 +2578,9 @@ void MessageHelper::SendOnPermissionsChangeNotification(
content[strings::msg_params] =
smart_objects::SmartObject(smart_objects::SmartType_Map);
- if (encryprion_required.is_initialized()) {
+ if (encryption_required.is_initialized()) {
content[strings::msg_params][strings::require_encryption] =
- static_cast<bool>(*encryprion_required);
+ static_cast<bool>(*encryption_required);
}
content[strings::msg_params]["permissionItem"] =
smart_objects::SmartObject(smart_objects::SmartType_Array);
@@ -2637,7 +2637,7 @@ void MessageHelper::SendOnPermissionsChangeNotification(
permission_item["rpcName"] = (*it_permissions).first;
const policy::RpcPermissions& rpc_permissions = (*it_permissions).second;
auto item_require_encryption = permission_item_encryption_flag_state(
- encryprion_required, rpc_permissions.require_encryption);
+ encryption_required, rpc_permissions.require_encryption);
if (item_require_encryption.is_initialized()) {
const bool require_encryption = *item_require_encryption;
permission_item[strings::require_encryption] = require_encryption;
diff --git a/src/components/application_manager/test/application_helper_test.cc b/src/components/application_manager/test/application_helper_test.cc
index d9d590a171..c03d78fee2 100644
--- a/src/components/application_manager/test/application_helper_test.cc
+++ b/src/components/application_manager/test/application_helper_test.cc
@@ -95,7 +95,7 @@ class ApplicationHelperTest : public testing::Test {
.WillByDefault(Return(true));
ON_CALL(mock_application_manager_settings_, stop_streaming_timeout())
.WillByDefault(Return(stop_streaming_timeout));
- ON_CALL(mock_application_manager_settings_, time_out_promt())
+ ON_CALL(mock_application_manager_settings_, time_out_prompt())
.WillByDefault(ReturnRef(kTimeoutPrompt));
CreateApplication();
diff --git a/src/components/application_manager/test/resumption/resumption_data_test.cc b/src/components/application_manager/test/resumption/resumption_data_test.cc
index e362064a78..8d7bd52c2c 100644
--- a/src/components/application_manager/test/resumption/resumption_data_test.cc
+++ b/src/components/application_manager/test/resumption/resumption_data_test.cc
@@ -292,9 +292,10 @@ void ResumptionDataTest::CheckMenuIcon(sm::SmartObject& res_list) {
void ResumptionDataTest::CheckHelpPrompt(sm::SmartObject& res_list) {
for (uint i = 0; i < tts_chunks_count; ++i) {
- std::string promt = (*help_prompt_)[i][am::strings::help_prompt].asString();
- std::string dict_promt = res_list[i][am::strings::help_prompt].asString();
- EXPECT_EQ(promt, dict_promt);
+ std::string prompt =
+ (*help_prompt_)[i][am::strings::help_prompt].asString();
+ std::string dict_prompt = res_list[i][am::strings::help_prompt].asString();
+ EXPECT_EQ(prompt, dict_prompt);
}
}
diff --git a/src/components/config_profile/src/profile.cc b/src/components/config_profile/src/profile.cc
index dd0dc50f44..d20b1d014a 100644
--- a/src/components/config_profile/src/profile.cc
+++ b/src/components/config_profile/src/profile.cc
@@ -146,8 +146,8 @@ const char* kBeforeUpdateHours = "UpdateBeforeHours";
const char* kAudioDataStoppedTimeoutKey = "AudioDataStoppedTimeout";
const char* kVideoDataStoppedTimeoutKey = "VideoDataStoppedTimeout";
const char* kMixingAudioSupportedKey = "MixingAudioSupported";
-const char* kHelpPromptKey = "HelpPromt";
-const char* kTimeoutPromptKey = "TimeOutPromt";
+const char* kHelpPromptKey = "HelpPrompt";
+const char* kTimeoutPromptKey = "TimeOutPrompt";
const char* kHelpTitleKey = "HelpTitle";
const char* kHelpCommandKey = "HelpCommand";
const char* kSystemFilesPathKey = "SystemFilesPath";
@@ -462,7 +462,7 @@ Profile::Profile()
, time_testing_port_(kDefaultTimeTestingPort)
, hmi_capabilities_file_name_(kDefaultHmiCapabilitiesFileName)
, help_prompt_()
- , time_out_promt_()
+ , time_out_prompt_()
, min_tread_stack_size_(threads::Thread::kMinStackSize)
, is_mixing_audio_supported_(false)
, is_redecoding_enabled_(false)
@@ -643,8 +643,8 @@ const std::vector<std::string>& Profile::help_prompt() const {
return help_prompt_;
}
-const std::vector<std::string>& Profile::time_out_promt() const {
- return time_out_promt_;
+const std::vector<std::string>& Profile::time_out_prompt() const {
+ return time_out_prompt_;
}
const std::vector<std::string>& Profile::vr_commands() const {
@@ -1689,7 +1689,7 @@ void Profile::UpdateValues() {
}
// Timeout prompt
- time_out_promt_.clear();
+ time_out_prompt_.clear();
std::string timeout_prompt_value;
if (ReadValue(
&timeout_prompt_value, kGlobalPropertiesSection, kTimeoutPromptKey)) {
@@ -1698,7 +1698,7 @@ void Profile::UpdateValues() {
while (str != NULL) {
// Default prompt should have delimiter included for each item
const std::string prompt_item = std::string(str) + tts_delimiter_;
- time_out_promt_.push_back(prompt_item);
+ time_out_prompt_.push_back(prompt_item);
LOG_UPDATED_VALUE(
prompt_item, kTimeoutPromptKey, kGlobalPropertiesSection);
str = strtok(NULL, ",");
diff --git a/src/components/config_profile/test/profile_test.cc b/src/components/config_profile/test/profile_test.cc
index 6dc0434440..c526a14115 100644
--- a/src/components/config_profile/test/profile_test.cc
+++ b/src/components/config_profile/test/profile_test.cc
@@ -255,14 +255,14 @@ TEST_F(ProfileTest, UpdateBool_ValueAppearsInFileTwice) {
TEST_F(ProfileTest, UpdateVectorOfString_ValueAppearsInFileTwice) {
// Default values
- std::vector<std::string> time_out_promt;
- EXPECT_EQ(time_out_promt, profile_.time_out_promt());
+ std::vector<std::string> time_out_prompt;
+ EXPECT_EQ(time_out_prompt, profile_.time_out_prompt());
// Change config file
profile_.set_config_file_name("smartDeviceLink_test.ini");
EXPECT_EQ("smartDeviceLink_test.ini", profile_.config_file_name());
// Update config file
- time_out_promt.push_back("Please say a command,");
- EXPECT_EQ(time_out_promt, profile_.time_out_promt());
+ time_out_prompt.push_back("Please say a command,");
+ EXPECT_EQ(time_out_prompt, profile_.time_out_prompt());
}
TEST_F(ProfileTest, UpdateString_ValueAppearsInFileTwice) {
diff --git a/src/components/config_profile/test/smartDeviceLink.ini b/src/components/config_profile/test/smartDeviceLink.ini
index 6ea131b095..f6e124a885 100644
--- a/src/components/config_profile/test/smartDeviceLink.ini
+++ b/src/components/config_profile/test/smartDeviceLink.ini
@@ -80,15 +80,15 @@ RecordingFileSource = audio.8bit.wav
; Recording file for audio pass thru
RecordingFileName = audio.wav
-; HelpPromt and TimeOutPrompt is a vector of strings separated by comma
+; HelpPrompt and TimeOutPrompt is a vector of strings separated by comma
[GLOBAL PROPERTIES]
; Delimiter, which will be appended to each TTS chunck, e.g. helpPrompt/timeoutPrompt
TTSDelimiter = ,
; Default prompt items, separated by comma
-HelpPromt = Please speak one of the following commands,Please say a command
+HelpPrompt = Please speak one of the following commands,Please say a command
; Default prompt items, separated by comma
-TimeOutPromt = Please speak one of the following commands,Please say a command
+TimeOutPrompt = Please speak one of the following commands,Please say a command
HelpTitle = Available Vr Commands List
; In case mobile app didn't send global properties default global properties will be sent after this timeout
; max value TTSGlobalPropertiesTimeout 64K
diff --git a/src/components/config_profile/test/smartDeviceLink_invalid_boolean.ini b/src/components/config_profile/test/smartDeviceLink_invalid_boolean.ini
index f93fa39597..66e270a197 100644
--- a/src/components/config_profile/test/smartDeviceLink_invalid_boolean.ini
+++ b/src/components/config_profile/test/smartDeviceLink_invalid_boolean.ini
@@ -80,15 +80,15 @@ RecordingFileSource = audio.8bit.wav
; Recording file for audio pass thru
RecordingFileName = audio.wav
-; HelpPromt and TimeOutPrompt is a vector of strings separated by comma
+; HelpPrompt and TimeOutPrompt is a vector of strings separated by comma
[GLOBAL PROPERTIES]
; Delimiter, which will be appended to each TTS chunck, e.g. helpPrompt/timeoutPrompt
TTSDelimiter = ,
; Default prompt items, separated by comma
-HelpPromt = Please speak one of the following commands,Please say a command
+HelpPrompt = Please speak one of the following commands,Please say a command
; Default prompt items, separated by comma
-TimeOutPromt = Please speak one of the following commands,Please say a command
+TimeOutPrompt = Please speak one of the following commands,Please say a command
HelpTitle = Available Vr Commands List
; In case mobile app didn't send global properties default global properties will be sent after this timeout
; max value TTSGlobalPropertiesTimeout 64K
diff --git a/src/components/config_profile/test/smartDeviceLink_invalid_int.ini b/src/components/config_profile/test/smartDeviceLink_invalid_int.ini
index 9c88a8950c..24dd1384b7 100644
--- a/src/components/config_profile/test/smartDeviceLink_invalid_int.ini
+++ b/src/components/config_profile/test/smartDeviceLink_invalid_int.ini
@@ -81,15 +81,15 @@ RecordingFileSource = audio.8bit.wav
; Recording file for audio pass thru
RecordingFileName = audio.wav
-; HelpPromt and TimeOutPrompt is a vector of strings separated by comma
+; HelpPrompt and TimeOutPrompt is a vector of strings separated by comma
[GLOBAL PROPERTIES]
; Delimiter, which will be appended to each TTS chunck, e.g. helpPrompt/timeoutPrompt
TTSDelimiter = ,
; Default prompt items, separated by comma
-HelpPromt = Please speak one of the following commands,Please say a command
+HelpPrompt = Please speak one of the following commands,Please say a command
; Default prompt items, separated by comma
-TimeOutPromt = Please speak one of the following commands,Please say a command
+TimeOutPrompt = Please speak one of the following commands,Please say a command
HelpTitle = Available Vr Commands List
; In case mobile app didn't send global properties default global properties will be sent after this timeout
; max value TTSGlobalPropertiesTimeout 64K
diff --git a/src/components/config_profile/test/smartDeviceLink_invalid_pairs.ini b/src/components/config_profile/test/smartDeviceLink_invalid_pairs.ini
index b389b0b492..d5b88138a1 100644
--- a/src/components/config_profile/test/smartDeviceLink_invalid_pairs.ini
+++ b/src/components/config_profile/test/smartDeviceLink_invalid_pairs.ini
@@ -82,15 +82,15 @@ RecordingFileSource = audio.8bit.wav
; Recording file for audio pass thru
RecordingFileName = audio.wav
-; HelpPromt and TimeOutPrompt is a vector of strings separated by comma
+; HelpPrompt and TimeOutPrompt is a vector of strings separated by comma
[GLOBAL PROPERTIES]
; Delimiter, which will be appended to each TTS chunck, e.g. helpPrompt/timeoutPrompt
TTSDelimiter = ,
; Default prompt items, separated by comma
-HelpPromt = Please speak one of the following commands,Please say a command
+HelpPrompt = Please speak one of the following commands,Please say a command
; Default prompt items, separated by comma
-TimeOutPromt = Please speak one of the following commands,Please say a command
+TimeOutPrompt = Please speak one of the following commands,Please say a command
HelpTitle = Available Vr Commands List
; In case mobile app didn't send global properties default global properties will be sent after this timeout
; max value TTSGlobalPropertiesTimeout 64K
diff --git a/src/components/config_profile/test/smartDeviceLink_invalid_string.ini b/src/components/config_profile/test/smartDeviceLink_invalid_string.ini
index f18b43cb41..a36faeead9 100644
--- a/src/components/config_profile/test/smartDeviceLink_invalid_string.ini
+++ b/src/components/config_profile/test/smartDeviceLink_invalid_string.ini
@@ -84,16 +84,16 @@ RecordingFileSource = 00012\\345/678'90abc!def@ghi#jkl$mno%pqr^stu*vwx:yz()ABC-D
; Recording file for audio pass thru
RecordingFileName = 0/0/0/1/2345678'90abc!def@ghi#jkl$mno%pqr^stu*vwx:yz()ABC-DEF_GHIJKL+MNO|PQR~STU{}WXY[]Z,01234567890a00012345678'90abc!def@ghi#jkl$mno%pqr^stu*vwx:yz()ABC-DEF_GHIJKL+MNO|PQR~STU{}WXY[]Z,01234567890a00012345678'90abc!def@ghi#jkl$mno%pqr^stu*vwx:yz()ABC-DEF_GHIJKL+MNO|PQR~STU{}WXY[]Z,01234567890a00012345678'90abc!def@ghi#jkl$mno%pqr^stu*vwx:yz()ABC-DEF_GHIJKL+MNO|PQR~STU{}WXY[]Z,01234567890a00012345678'90abc!def@ghi#jkl$mno%pqr^stu*vwx:yz()ABC-DEF_GHIJKL+MNO|PQR~STU{}WXY[]Z,01234567890abc!def@ghi
-; HelpPromt and TimeOutPrompt is a vector of strings separated by comma
+; HelpPrompt and TimeOutPrompt is a vector of strings separated by comma
[GLOBAL PROPERTIES]
; Delimiter, which will be appended to each TTS chunck, e.g. helpPrompt/timeoutPrompt
; ---------- words instead of coma
TTSDelimiter = coma and point
; Default prompt items, separated by comma
-HelpPromt = Please speak one of the following commands,Please say a command
+HelpPrompt = Please speak one of the following commands,Please say a command
; Default prompt items, separated by comma
-TimeOutPromt = Please speak one of the following commands,Please say a command
+TimeOutPrompt = Please speak one of the following commands,Please say a command
HelpTitle = 0/0/0/1/2345678'90abc!def@ghi#jkl$mno%pqr^stu*vwx:yz()ABC-DEF_GHIJKL+MNO|PQR~STU{}WXY[]Z,01234567890a00012345678'90abc!def@ghi#jkl$mno%pqr^stu*vwx:yz()ABC-DEF_GHIJKL+MNO|PQR~STU{}WXY[]Z,01234567890a00012345678'90abc!def@ghi#jkl$mno%pqr^stu*vwx:yz()ABC-DEF_GHIJKL+MNO|PQR~STU{}WXY[]Z,01234567890a00012345678'90abc!def@ghi#jkl$mno%pqr^stu*vwx:yz()ABC-DEF_GHIJKL+MNO|PQR~STU{}WXY[]Z,01234567890a00012345678'90abc!def@ghi#jkl$mno%pqr^stu*vwx:yz()ABC-DEF_GHIJKL+MNO|PQR~STU{}WXY[]Z,01234567890abc!def@ghi
; In case mobile app didn't send global properties default global properties will be sent after this timeout
; max value TTSGlobalPropertiesTimeout 64K
diff --git a/src/components/config_profile/test/smartDeviceLink_test.ini b/src/components/config_profile/test/smartDeviceLink_test.ini
index 9791544e16..f6e7e0df23 100644
--- a/src/components/config_profile/test/smartDeviceLink_test.ini
+++ b/src/components/config_profile/test/smartDeviceLink_test.ini
@@ -85,16 +85,16 @@ RecordingFileSource = audio.8bit.wav
RecordingFileName = video.wav
RecordingFileName = audio.wav
-; HelpPromt and TimeOutPrompt is a vector of strings separated by comma
+; HelpPrompt and TimeOutPrompt is a vector of strings separated by comma
[GLOBAL PROPERTIES]
; Delimiter, which will be appended to each TTS chunck, e.g. helpPrompt/timeoutPrompt
TTSDelimiter = ,
; Default prompt items, separated by comma
-HelpPromt = Please speak one of the following commands,Please say a command
+HelpPrompt = Please speak one of the following commands,Please say a command
; Default prompt items, separated by comma
-TimeOutPromt = Please say a command
-TimeOutPromt = Please speak one of the following commands,Please say a command
+TimeOutPrompt = Please say a command
+TimeOutPrompt = Please speak one of the following commands,Please say a command
HelpTitle = Available Vr Commands List
; In case mobile app didn't send global properties default global properties will be sent after this timeout
; max value TTSGlobalPropertiesTimeout 64K
diff --git a/src/components/connection_handler/test/smartDeviceLink.ini b/src/components/connection_handler/test/smartDeviceLink.ini
index 109003eb5f..f8369ee6ff 100644
--- a/src/components/connection_handler/test/smartDeviceLink.ini
+++ b/src/components/connection_handler/test/smartDeviceLink.ini
@@ -88,15 +88,15 @@ RecordingFileSource = audio.8bit.wav
; Recording file for audio pass thru
RecordingFileName = audio.wav
-; HelpPromt and TimeOutPrompt is a vector of strings separated by comma
+; HelpPrompt and TimeOutPrompt is a vector of strings separated by comma
[GLOBAL PROPERTIES]
; Delimiter, which will be appended to each TTS chunck, e.g. helpPrompt/timeoutPrompt
TTSDelimiter = ,
; Default prompt items, separated by comma
-HelpPromt = Please speak one of the following commands,Please say a command
+HelpPrompt = Please speak one of the following commands,Please say a command
; Default prompt items, separated by comma
-TimeOutPromt = Please speak one of the following commands,Please say a command
+TimeOutPrompt = Please speak one of the following commands,Please say a command
HelpTitle = Available Vr Commands List
; In case mobile app didn't send global properties default global properties will be sent after this timeout
; max value TTSGlobalPropertiesTimeout 64K
diff --git a/src/components/include/application_manager/application_manager_settings.h b/src/components/include/application_manager/application_manager_settings.h
index 524feed6e5..c0b4c259fe 100644
--- a/src/components/include/application_manager/application_manager_settings.h
+++ b/src/components/include/application_manager/application_manager_settings.h
@@ -72,7 +72,7 @@ class ApplicationManagerSettings : public RequestControlerSettings,
virtual const std::string& tts_delimiter() const = 0;
virtual const uint32_t& put_file_in_none() const = 0;
virtual const std::string& sdl_version() const = 0;
- virtual const std::vector<std::string>& time_out_promt() const = 0;
+ virtual const std::vector<std::string>& time_out_prompt() const = 0;
virtual const std::string& hmi_capabilities_file_name() const = 0;
virtual const std::string& video_server_type() const = 0;
virtual const std::string& audio_server_type() const = 0;
diff --git a/src/components/include/test/application_manager/mock_application_manager_settings.h b/src/components/include/test/application_manager/mock_application_manager_settings.h
index 998ff252fe..ba850a278a 100644
--- a/src/components/include/test/application_manager/mock_application_manager_settings.h
+++ b/src/components/include/test/application_manager/mock_application_manager_settings.h
@@ -78,7 +78,7 @@ class MockApplicationManagerSettings
MOCK_CONST_METHOD0(tts_delimiter, const std::string&());
MOCK_CONST_METHOD0(put_file_in_none, const uint32_t&());
MOCK_CONST_METHOD0(sdl_version, const std::string&());
- MOCK_CONST_METHOD0(time_out_promt, const std::vector<std::string>&());
+ MOCK_CONST_METHOD0(time_out_prompt, const std::vector<std::string>&());
MOCK_CONST_METHOD0(hmi_capabilities_file_name, const std::string&());
MOCK_CONST_METHOD0(video_server_type, const std::string&());
MOCK_CONST_METHOD0(audio_server_type, const std::string&());
diff --git a/src/components/policy/policy_external/include/policy/policy_table/types.h b/src/components/policy/policy_external/include/policy/policy_table/types.h
index 11c76bdd68..b0b62db82a 100644
--- a/src/components/policy/policy_external/include/policy/policy_table/types.h
+++ b/src/components/policy/policy_external/include/policy/policy_table/types.h
@@ -230,6 +230,8 @@ struct ApplicationParams : PolicyBase {
Optional<Integer<uint32_t, 0, UINT_MAX> > heart_beat_timeout_ms;
mutable Optional<ModuleTypes> moduleType;
Optional<String<0, 65535> > certificate;
+ Optional<Boolean> encryption_required;
+
// Cloud application params
Optional<Enum<HybridAppPreference> > hybrid_app_preference;
Optional<String<0, 255> > endpoint;
@@ -241,7 +243,6 @@ struct ApplicationParams : PolicyBase {
// App Service Params
Optional<AppServiceParameters> app_service_parameters;
Optional<Boolean> allow_unknown_rpc_passthrough;
- Optional<Boolean> encryption_required;
public:
ApplicationParams();
diff --git a/src/components/policy/policy_external/src/policy_manager_impl.cc b/src/components/policy/policy_external/src/policy_manager_impl.cc
index 6868b9060c..a75dfea24d 100644
--- a/src/components/policy/policy_external/src/policy_manager_impl.cc
+++ b/src/components/policy/policy_external/src/policy_manager_impl.cc
@@ -1551,7 +1551,7 @@ void PolicyManagerImpl::GetPermissionsForApp(
// Groups that allowed by default but can be changed by the user
FunctionalGroupIDs preconsented_groups = group_types[kTypePreconsented];
- // Groups which has user consent promt but there is no any consnets now.
+ // Groups which has user consent prompt but there is no any consent now.
FunctionalGroupIDs unconsented_groups = group_types[kTypeUnconsented];
// Pull common groups from allowed and preconsented parts.
diff --git a/src/components/policy/policy_external/src/policy_table/types.cc b/src/components/policy/policy_external/src/policy_table/types.cc
index f0ea154f94..3a957f51a6 100644
--- a/src/components/policy/policy_external/src/policy_table/types.cc
+++ b/src/components/policy/policy_external/src/policy_table/types.cc
@@ -346,6 +346,7 @@ ApplicationParams::ApplicationParams(const Json::Value* value__)
, heart_beat_timeout_ms(impl::ValueMember(value__, "heart_beat_timeout_ms"))
, moduleType(impl::ValueMember(value__, "moduleType"))
, certificate(impl::ValueMember(value__, "certificate"))
+ , encryption_required(impl::ValueMember(value__, "encryption_required"))
, hybrid_app_preference(impl::ValueMember(value__, "hybrid_app_preference"))
, endpoint(impl::ValueMember(value__, "endpoint"))
, enabled(impl::ValueMember(value__, "enabled"))
@@ -354,8 +355,7 @@ ApplicationParams::ApplicationParams(const Json::Value* value__)
, icon_url(impl::ValueMember(value__, "icon_url"))
, app_service_parameters(impl::ValueMember(value__, "app_services"))
, allow_unknown_rpc_passthrough(
- impl::ValueMember(value__, "allow_unknown_rpc_passthrough"))
- , encryption_required(impl::ValueMember(value__, "encryption_required")) {}
+ impl::ValueMember(value__, "allow_unknown_rpc_passthrough")) {}
Json::Value ApplicationParams::ToJsonValue() const {
Json::Value result__(PolicyBase::ToJsonValue());
diff --git a/src/components/policy/policy_regular/include/policy/policy_table/types.h b/src/components/policy/policy_regular/include/policy/policy_table/types.h
index 2ffbf2e7ec..61ec6e8f15 100644
--- a/src/components/policy/policy_regular/include/policy/policy_table/types.h
+++ b/src/components/policy/policy_regular/include/policy/policy_table/types.h
@@ -197,6 +197,8 @@ struct ApplicationParams : PolicyBase {
Optional<Integer<uint32_t, 0, UINT_MAX> > heart_beat_timeout_ms;
Optional<String<0, 65535> > certificate;
mutable Optional<ModuleTypes> moduleType;
+ Optional<Boolean> encryption_required;
+
// Cloud application params
Optional<Enum<HybridAppPreference> > hybrid_app_preference;
Optional<String<0, 255> > endpoint;
@@ -208,7 +210,6 @@ struct ApplicationParams : PolicyBase {
// App Service Params
Optional<AppServiceParameters> app_service_parameters;
Optional<Boolean> allow_unknown_rpc_passthrough;
- Optional<Boolean> encryption_required;
public:
ApplicationParams();
diff --git a/src/components/policy/policy_regular/src/policy_table/types.cc b/src/components/policy/policy_regular/src/policy_table/types.cc
index 3029ebb067..32e148fbf7 100644
--- a/src/components/policy/policy_regular/src/policy_table/types.cc
+++ b/src/components/policy/policy_regular/src/policy_table/types.cc
@@ -271,6 +271,7 @@ ApplicationParams::ApplicationParams(const Json::Value* value__)
, heart_beat_timeout_ms(impl::ValueMember(value__, "heart_beat_timeout_ms"))
, certificate(impl::ValueMember(value__, "certificate"))
, moduleType(impl::ValueMember(value__, "moduleType"))
+ , encryption_required(impl::ValueMember(value__, "encryption_required"))
, hybrid_app_preference(impl::ValueMember(value__, "hybrid_app_preference"))
, endpoint(impl::ValueMember(value__, "endpoint"))
, enabled(impl::ValueMember(value__, "enabled"))
@@ -279,8 +280,7 @@ ApplicationParams::ApplicationParams(const Json::Value* value__)
, icon_url(impl::ValueMember(value__, "icon_url"))
, app_service_parameters(impl::ValueMember(value__, "app_services"))
, allow_unknown_rpc_passthrough(
- impl::ValueMember(value__, "allow_unknown_rpc_passthrough"))
- , encryption_required(impl::ValueMember(value__, "encryption_required")) {}
+ impl::ValueMember(value__, "allow_unknown_rpc_passthrough")) {}
Json::Value ApplicationParams::ToJsonValue() const {
Json::Value result__(PolicyBase::ToJsonValue());
diff --git a/src/components/config_profile/include/config_profile/profile.h b/src/components/config_profile/include/config_profile/profile.h
index 5489a962e8..99434fc2d7 100644
--- a/src/components/config_profile/include/config_profile/profile.h
+++ b/src/components/config_profile/include/config_profile/profile.h
@@ -212,14 +212,14 @@ class Profile : public protocol_handler::ProtocolHandlerSettings,
const std::string& hmi_capabilities_file_name() const;
/**
* @brief Returns help promt vector
*/
const std::vector<std::string>& help_prompt() const;
/**
* @brief Returns help promt vector
*/
- const std::vector<std::string>& time_out_promt() const;
+ const std::vector<std::string>& time_out_prompt() const;
/**
* @brief Returns vr commands default for all apps
@@ -952,7 +952,7 @@ class Profile : public protocol_handler::ProtocolHandlerSettings,
uint16_t time_testing_port_;
std::string hmi_capabilities_file_name_;
std::vector<std::string> help_prompt_;
- std::vector<std::string> time_out_promt_;
+ std::vector<std::string> time_out_prompt_;
std::vector<std::string> vr_commands_;
uint64_t min_tread_stack_size_;
bool is_mixing_audio_supported_;
@@ -212,14 +212,14 @@ class Profile : public protocol_handler::ProtocolHandlerSettings,
const std::string& hmi_capabilities_file_name() const;
/**
- * @brief Returns help promt vector
+ * @brief Returns help prompt vector
*/
const std::vector<std::string>& help_prompt() const;
@@ -212,14 +212,14 @@ class Profile : public protocol_handler::ProtocolHandlerSettings,
const std::vector<std::string>& help_prompt() const;
/**
- * @brief Returns help promt vector
+ * @brief Returns help prompt vector
*/